@@ -21,10 +21,10 @@ def djsciops(args: list = None):
     command = parser.add_subparsers(dest="command")
     axon = command.add_parser("axon", description="Manage object store data.")
     subcommand = axon.add_subparsers(dest="subcommand")
-    axon_cp = subcommand.add_parser(
-        "cp", description="Copy objects by uploading to object store."
+    axon_upload = subcommand.add_parser(
+        "upload", description="Copy objects by uploading to object store."
     )
-    required_named = axon_cp.add_argument_group("required named arguments")
+    required_named = axon_upload.add_argument_group("required named arguments")
 
     required_named.add_argument(
         "source",
@@ -37,15 +37,16 @@ def djsciops(args: list = None):
         help="Target directory in object store.",
     )
 
-    kwargs = vars(parser.parse_args(args))
-    if kwargs["command"] == "axon" and kwargs["subcommand"] == "cp":
+    kwargs = vars(parser.parse_args(args or ["-h"]))
+    config = djsciops_settings.get_config()
+    if kwargs["command"] == "axon" and kwargs["subcommand"] == "upload":
         djsciops_axon.upload_files(
             session=djsciops_authentication.Session(
-                aws_account_id=djsciops_settings.config["aws"]["account_id"],
-                s3_role=djsciops_settings.config["s3"]["role"],
-                auth_client_id=djsciops_settings.config["djauth"]["client_id"],
+                aws_account_id=config["aws"]["account_id"],
+                s3_role=config["s3"]["role"],
+                auth_client_id=config["djauth"]["client_id"],
             ),
-            s3_bucket=djsciops_settings.config["s3"]["bucket"],
+            s3_bucket=config["s3"]["bucket"],
             source=kwargs["source"],
             destination=kwargs["destination"],
         )
